#!/usr/bin/python3
# -*- coding=utf-8 -*-
r"""

"""


extension_registry = {}


class BaseLoader:
    def __init_subclass__(cls, **kwargs):
        if not hasattr(cls, '_FILE_EXTENSIONS'):
            raise AttributeError("missing attribute '_FILE_EXTENSIONS'")
        if getattr(cls, 'load') is BaseLoader.load:
            raise NotImplementedError('please override the .load() method')
        for extension in cls._FILE_EXTENSIONS:
            extension_registry[extension] = cls

    def __init__(self, fp):
        self.fp = fp

    def load(self):
        raise NotImplementedError()



#!/usr/bin/python3
# -*- coding=utf-8 -*-
r"""

"""
import os
from .baseloader import BaseLoader, extension_registry
from .json_loader import JsonLoader
try:
    from .toml_loader import TomlLoader
except NotImplementedError:
    pass
try:
    from .yaml_loader import YamlLoader
except NotImplementedError:
    pass


def loadConfig(fp):
    fp = os.path.abspath(fp)
    extension = os.path.splitext(fp)[1]
    loader_class = extension_registry.get(extension, None)
    if loader_class is None:
        raise TypeError('unsupported filetype')
    loader = loader_class(fp)
    return loader.load()



#!/usr/bin/python3
# -*- coding=utf-8 -*-
r"""

"""
import configparser
from . import baseloader


class ConfigLoader(baseloader.BaseLoader):
    _FILE_EXTENSIONS = ('.ini', '.conf', '.config')

    def load(self):
        parser = configparser.ConfigParser()
        with open(self.fp, 'r') as file:
            parser.read_file(file)
        return parser



#!/usr/bin/python3
# -*- coding=utf-8 -*-
r"""

"""
from .finder import ConfigFinder


def findConfig(name, *, namespace=None, **kwargs):
    return ConfigFinder(name=name, namespace=namespace, **kwargs).find()



#!/usr/bin/python3
# -*- coding=utf-8 -*-
r"""

"""
import sys
import setuptools
sys.path.append('./src')
from config_lib import __author__, __version__


setuptools.setup(
    name="config-library",
    version=__version__,
    author=__author__,
    # author_email="author@example.com",
    description="utility library to find and load configuration files",
    long_description=open("README.md", "r", encoding="utf-8").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/PlayerG9/py-config-lib",
    project_urls={
        "Author Github": "https://github.com/PlayerG9",
        "Bug Tracker": "https://github.com/PlayerG9/py-config-lib/issues",
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    package_dir={"": "src"},
    packages=setuptools.find_packages(where="src"),
    python_requires=">=3.5",
)



#!/usr/bin/python3
# -*- coding=utf-8 -*-
r"""

"""
import json
from . import baseloader


class JsonLoader(baseloader.BaseLoader):
    _FILE_EXTENSIONS = ('.json',)

    def load(self):
        with open(self.fp, 'r') as file:
            return json.load(file)



#!/usr/bin/python3
# -*- coding=utf-8 -*-
r"""

"""
try:
    import yaml
except ModuleNotFoundError:
    raise NotImplementedError('please install pyyaml for this')
from . import baseloader


class YamlLoader(baseloader.BaseLoader):
    _FILE_EXTENSIONS = ('.yaml',)

    def load(self):
        with open(self.fp, 'r') as file:
            return yaml.save_load(file)
